==> pirated_data-0.0.1.tar.gz: pirated_data-0.0.1/README.md <==
<p align="center">
  <a href="#">
    <img alt="Pirated-Data" src="https://github.com/studyandmasti/pirated-data/blob/main/JavaScript/package/Images/pirated-data-logo.png?raw=true"width="100" height="100" />
  </a>
</p>
<h1 align="center">
 Pirated-Data
</h1>

 ![CodeFactor](https://www.codefactor.io/repository/github/satya319/pirated-data/badge/main)
 **Install the package via pypi**

```

pip install pirated-data

```

## Data provided for the user are 



- [First name](#First-name)

- [Last name](#Last-name)

- [Age](#Age)

- [Mobile number](#Mobile-number)

- [Aadhar number ( unique identification number)](#Aadhar-number-(unique-identification-number))

- [Email-id](#Email-id)

- [Upi-Id](#Upi-Id)

- [User Id](#User-Id)

- [Password](#Password)

- [PanCard ID](#PanCard-ID)

- [Passport Number](#Passport-Number)

- [Driving license number](#Driving-license-number)

- [Random number](#Random-Number)

- [Financial card](#Financial-card)

  - [Card Number](#Card-Number)

  - [Card Holder Name](#Card-Holder-Name)

  - [Validthru](#Validthru)

  - [Cvv](#Cvv)

- [Person's Biological Data](#Person's-Biological-Data)

  - [First name](#First-name)

  - [Last name](#Last-name)

  - [Gender](#Gender)

  - [Hair Color](#Hair-Color)

  - [Date of birth](#Date-of-birth)

  - [Age](#Age)

  - [Eye Color](#Eye-Color)

  - [Blood group](#Blood-group)

  - [Weight](#Weight)

  - [Body Skin Color](#Body-Skin-Color)

- [Address](#Address)

  - [Full Name](#Full-Name)

  - [State Name](#State-Name)

  - [District Name](#District-Name)







### Pirated-Data also supports generate sets of data

- [Address](#Address)

  - [Full Name](#Full-Name)

  - [State Name (India)](#State-Name-(-India-))

  - [District Name (India)](#District-Name-(-India-))

- [Biological Details](#Biological-Details)

  - [Full name](#Full-name)

  - [Gender](#Gender)

  - [Hair Color](#Hair-Color)

  - [Date of birth](#Date-of-birth)

  - [Age](#Age)

  - [Eye Color](#Eye-Color)

  - [Blood group](#Blood-group)

  - [Weight](#Weight)

  - [Body Skin Color](#Body-Skin-Color)



### Import to your TypeScript project 

```

import userData from 'pirated-data';

```

Example :</br>

```

import userData from 'pirated-data';

let fulName = userData.userIdGenerator();

    console.log("pirated data test: ",fulName);

```

### Import to your JavaScript project

```

const userData = require('pirated-data');

```

Example :</br>

```

import pirated_data as pd
x = pd.lastNameGenerator()
print(x)
```

### Check the below table for function list and use JavaScript function

| Function   Name | Java | JavaScript | python |
|---|---|---|---|
| firstNameGenerator() | Yes | Yes | yes |
| lastNameGenerator() | Yes | Yes | yes |
| fullNameGenerator() | Yes | Yes | yes |
| mobileNumberGenerator() | Yes | Yes | No |
| aadharNumberGenerator() | Yes | Yes | No |
| emailIdGenerator() | Yes | Yes | No |
| userIdGenerator() | Yes | Yes | No |
| passwordGenerator(int length) | Yes | Yes | No |
| randomNumberGenerator() | Yes | No | No |
| randomNumberGenerator(int MaxNumber) | Yes | Yes | No |
| panCardId() | Yes | Yes | No |
| upiIdGenerator() | Yes | Yes | No |
| hairColorGenerator() | Yes | Yes | No |
| genderGenerator() | Yes | Yes | No |
| birthDateTimeGenerator() | Yes | Yes | No |
| eyeColorGenerator() | Yes | Yes | No |
| bloodGroupGenerator() | Yes | Yes | No 
| skinColorGenerator() | Yes | Yes | No |
| weightGenerator() | Yes | Yes | No |
| ageCalculation() | Yes | Yes | No |
| passportNumber() | Yes | Yes | No |
| drivinglicenseGenerator() | No | Yes | No |
| BiologicalData() | No | Yes | No |
| stateGenerator() | No | Yes | No |
| distGenerator() | No | Yes | No |
| addressGenerator() | No | Yes | No |
| financialCardGenerator() | No | Yes | No |
| hugeAddressGenerator(desiredDataSetNumber) | No | Yes | No |
| hugeBiologicalDataGenerator(desiredDataSetNumber) | No | Yes | No |

## Need More feature

_________________________________

If you want to more feature of this package just create an issue [Here.](https://github.com/satya319/pirated-data/issues)

==> pirated_data-0.0.2.tar.gz: pirated_data-0.0.2/README.md <==
<p align="center">
  <a href="#">
    <img alt="Pirated-Data" src="https://github.com/studyandmasti/pirated-data/blob/main/JavaScript/package/Images/pirated-data-logo.png?raw=true"width="100" height="100" />
  </a>
</p>
<h1 align="center">
 Pirated-Data
</h1>

 ![CodeFactor](https://www.codefactor.io/repository/github/satya319/pirated-data/badge/main)
 **Install the package via pypi**

```

pip install pirated-data

```

## Data provided for the user are 



- [First name](#First-name)

- [Last name](#Last-name)

- [Age](#Age)

- [Mobile number](#Mobile-number)

- [Aadhar number ( unique identification number)](#Aadhar-number-(unique-identification-number))

- [Email-id](#Email-id)

- [Upi-Id](#Upi-Id)

- [User Id](#User-Id)

- [Password](#Password)

- [PanCard ID](#PanCard-ID)

- [Passport Number](#Passport-Number)

- [Driving license number](#Driving-license-number)

- [Random number](#Random-Number)

- [Financial card](#Financial-card)

  - [Card Number](#Card-Number)

  - [Card Holder Name](#Card-Holder-Name)

  - [Validthru](#Validthru)

  - [Cvv](#Cvv)

- [Person's Biological Data](#Person's-Biological-Data)

  - [First name](#First-name)

  - [Last name](#Last-name)

  - [Gender](#Gender)

  - [Hair Color](#Hair-Color)

  - [Date of birth](#Date-of-birth)

  - [Age](#Age)

  - [Eye Color](#Eye-Color)

  - [Blood group](#Blood-group)

  - [Weight](#Weight)

  - [Body Skin Color](#Body-Skin-Color)

- [Address](#Address)

  - [Full Name](#Full-Name)

  - [State Name](#State-Name)

  - [District Name](#District-Name)







### Pirated-Data also supports generate sets of data

- [Address](#Address)

  - [Full Name](#Full-Name)

  - [State Name (India)](#State-Name-(-India-))

  - [District Name (India)](#District-Name-(-India-))

- [Biological Details](#Biological-Details)

  - [Full name](#Full-name)

  - [Gender](#Gender)

  - [Hair Color](#Hair-Color)

  - [Date of birth](#Date-of-birth)

  - [Age](#Age)

  - [Eye Color](#Eye-Color)

  - [Blood group](#Blood-group)

  - [Weight](#Weight)

  - [Body Skin Color](#Body-Skin-Color)

### Import to your python project

```

import pirated_data as pd

```

Example :</br>

```

import pirated_data as pd
x = pd.lastNameGenerator()
print(x)
```

### Check the below table for function list and use JavaScript function

| Function   Name | Java | JavaScript | python |
|---|---|---|---|
| firstNameGenerator() | Yes | Yes | yes |
| lastNameGenerator() | Yes | Yes | yes |
| fullNameGenerator() | Yes | Yes | yes |
| mobileNumberGenerator() | Yes | Yes | yes |
| aadharNumberGenerator() | Yes | Yes | yes |
| emailIdGenerator() | Yes | Yes | yes |
| userIdGenerator() | Yes | Yes | yes |
| passwordGenerator(int length) | Yes | Yes | yes |
| randomNumberGenerator() | Yes | No | No |
| randomNumberGenerator(int MaxNumber) | Yes | Yes | No |
| panCardId() | Yes | Yes | Yes |
| upiIdGenerator() | Yes | Yes | Yes |
| hairColorGenerator() | Yes | Yes | Yes |
| genderGenerator() | Yes | Yes | Yes |
| birthDateTimeGenerator() | Yes | Yes | No |
| eyeColorGenerator() | Yes | Yes | Yes |
| bloodGroupGenerator() | Yes | Yes | Yes | 
| skinColorGenerator() | Yes | Yes | Yes |
| weightGenerator() | Yes | Yes | Yes |
| ageCalculation() | Yes | Yes | No |
| passportNumber() | Yes | Yes | Yes |
| drivinglicenseGenerator() | No | Yes | No |
| BiologicalData() | No | Yes | No |
| stateGenerator() | No | Yes | No |
| distGenerator() | No | Yes | No |
| addressGenerator() | No | Yes | No |
| financialCardGenerator() | No | Yes | Yes |
| hugeAddressGenerator(desiredDataSetNumber) | No | Yes | No |
| hugeBiologicalDataGenerator(desiredDataSetNumber) | No | Yes | No |

## Need More feature

_________________________________

If you want to more feature of this package just create an issue [Here.](https://github.com/satya319/pirated-data/issues)
